@@ -1,6 +1,6 @@
 from .components.buildx import Builder
 from .components.config import Config
-from .components.container import Container
+from .components.container import Container, ContainerStats
 from .components.context import Context
 from .components.image import Image
 from .components.network import Network
@@ -8,6 +8,7 @@ from .components.node import Node
 from .components.service import Service
 from .components.stack import Stack
 from .components.system import SystemInfo
+from .components.task import Task
 from .components.volume import Volume
 from .docker_client import DockerClient
 from .utils import DockerException
